==> qtjambi-qt3dinput-jre8-5.15.5-sources.jar: io/qt/qt3d/input/QInputSequence.java <==
package io.qt.qt3d.input;


/**
 * <p>Represents a set of QAbstractActionInput's that must be triggerd one after the other</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3dinput-qinputsequence.html">Qt3DInput::QInputSequence</a></p>
 */
public class QInputSequence extends io.qt.qt3d.input.QAbstractActionInput
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QInputSequence.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qinputsequence.html#buttonInterval-prop">Qt3DInput::QInputSequence::buttonIntervalChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="buttonInterval")
    public final Signal1<@io.qt.QtPrimitiveType Integer> buttonIntervalChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qinputsequence.html#timeout-prop">Qt3DInput::QInputSequence::timeoutChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="timeout")
    public final Signal1<@io.qt.QtPrimitiveType Integer> timeoutChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QInputSequence(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QInputSequence() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qinputsequence.html#QInputSequence">Qt3DInput::QInputSequence::QInputSequence(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QInputSequence(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QInputSequence instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qinputsequence.html#addSequence">Qt3DInput::QInputSequence::addSequence(Qt3DInput::QAbstractActionInput*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addSequence(io.qt.qt3d.input.QAbstractActionInput input){
        addSequence_native_Qt3DInput_QAbstractActionInput_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(input));
    }
    
    @io.qt.QtUninvokable
    private native void addSequence_native_Qt3DInput_QAbstractActionInput_ptr(long __this__nativeId, long input);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qinputsequence.html#buttonInterval">Qt3DInput::QInputSequence::buttonInterval()const</a></p>
     */
    @io.qt.QtPropertyReader(name="buttonInterval")
    @io.qt.QtUninvokable
    public final int buttonInterval(){
        return buttonInterval_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int buttonInterval_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qinputsequence.html#removeSequence">Qt3DInput::QInputSequence::removeSequence(Qt3DInput::QAbstractActionInput*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeSequence(io.qt.qt3d.input.QAbstractActionInput input){
        removeSequence_native_Qt3DInput_QAbstractActionInput_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(input));
    }
    
    @io.qt.QtUninvokable
    private native void removeSequence_native_Qt3DInput_QAbstractActionInput_ptr(long __this__nativeId, long input);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qinputsequence.html#sequences">Qt3DInput::QInputSequence::sequences()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.input.QAbstractActionInput> sequences(){
        return sequences_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.input.QAbstractActionInput> sequences_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qinputsequence.html#buttonInterval-prop">Qt3DInput::QInputSequence::setButtonInterval(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="buttonInterval")
    public final void setButtonInterval(int buttonInterval){
        setButtonInterval_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), buttonInterval);
    }
    
    private native void setButtonInterval_native_int(long __this__nativeId, int buttonInterval);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qinputsequence.html#timeout-prop">Qt3DInput::QInputSequence::setTimeout(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="timeout")
    public final void setTimeout(int timeout){
        setTimeout_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), timeout);
    }
    
    private native void setTimeout_native_int(long __this__nativeId, int timeout);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qinputsequence.html#timeout">Qt3DInput::QInputSequence::timeout()const</a></p>
     */
    @io.qt.QtPropertyReader(name="timeout")
    @io.qt.QtUninvokable
    public final int timeout(){
        return timeout_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int timeout_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QInputSequence(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QInputSequence(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QInputSequence instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3dinput-jre8-6.3.0-sources.jar: io/qt/qt3d/input/QInputSequence.java <==
package io.qt.qt3d.input;


/**
 * <p>Represents a set of QAbstractActionInput's that must be triggerd one after the other</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3dinput-qinputsequence.html">Qt3DInput::QInputSequence</a></p>
 */
public class QInputSequence extends io.qt.qt3d.input.QAbstractActionInput
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QInputSequence.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qinputsequence.html#buttonInterval-prop">Qt3DInput::QInputSequence::buttonIntervalChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="buttonInterval")
    public final Signal1<@io.qt.QtPrimitiveType Integer> buttonIntervalChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qinputsequence.html#timeout-prop">Qt3DInput::QInputSequence::timeoutChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="timeout")
    public final Signal1<@io.qt.QtPrimitiveType Integer> timeoutChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QInputSequence(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QInputSequence() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qinputsequence.html#QInputSequence">Qt3DInput::QInputSequence::QInputSequence(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QInputSequence(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QInputSequence instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qinputsequence.html#addSequence">Qt3DInput::QInputSequence::addSequence(Qt3DInput::QAbstractActionInput*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addSequence(io.qt.qt3d.input.QAbstractActionInput input){
        addSequence_native_Qt3DInput_QAbstractActionInput_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(input));
    }
    
    @io.qt.QtUninvokable
    private native void addSequence_native_Qt3DInput_QAbstractActionInput_ptr(long __this__nativeId, long input);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qinputsequence.html#buttonInterval">Qt3DInput::QInputSequence::buttonInterval()const</a></p>
     */
    @io.qt.QtPropertyReader(name="buttonInterval")
    @io.qt.QtUninvokable
    public final int buttonInterval(){
        return buttonInterval_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int buttonInterval_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qinputsequence.html#removeSequence">Qt3DInput::QInputSequence::removeSequence(Qt3DInput::QAbstractActionInput*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeSequence(io.qt.qt3d.input.QAbstractActionInput input){
        removeSequence_native_Qt3DInput_QAbstractActionInput_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(input));
    }
    
    @io.qt.QtUninvokable
    private native void removeSequence_native_Qt3DInput_QAbstractActionInput_ptr(long __this__nativeId, long input);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qinputsequence.html#sequences">Qt3DInput::QInputSequence::sequences()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.qt3d.input.QAbstractActionInput> sequences(){
        return sequences_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.qt3d.input.QAbstractActionInput> sequences_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qinputsequence.html#buttonInterval-prop">Qt3DInput::QInputSequence::setButtonInterval(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="buttonInterval")
    public final void setButtonInterval(int buttonInterval){
        setButtonInterval_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), buttonInterval);
    }
    
    private native void setButtonInterval_native_int(long __this__nativeId, int buttonInterval);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qinputsequence.html#timeout-prop">Qt3DInput::QInputSequence::setTimeout(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="timeout")
    public final void setTimeout(int timeout){
        setTimeout_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), timeout);
    }
    
    private native void setTimeout_native_int(long __this__nativeId, int timeout);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qinputsequence.html#timeout">Qt3DInput::QInputSequence::timeout()const</a></p>
     */
    @io.qt.QtPropertyReader(name="timeout")
    @io.qt.QtUninvokable
    public final int timeout(){
        return timeout_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int timeout_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QInputSequence(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QInputSequence(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QInputSequence instance, QDeclarativeConstructor constructor);
    
}
